==> rebass-0.0.1.tgz: package/src/modal.jsx <==

var React = require('react');
var ThemeMixin = require('./theme-mixin');

module.exports = React.createClass({

  mixins: [ThemeMixin],

  getDefaultProps: function() {
    return {
      isOpen: false,
      flush: false,
      fullBleed: false,
      size: 'medium',
      header: '',
      theme: 'white',
      onDismiss: function() {}
    }
  },

  render: function() {

    var isOpen = this.props.isOpen;
    var header = this.props.header;
    var classes = this.getThemeClasses();
    classes.body = this.props.flush ? '' : 'p2';
    classes.header = 'flex flex-center ' + classes.main + (classes.border ? ' border-bottom' : '');
    classes.container = 'flex flex-center overflow-auto bg-darken-3 ' + (this.props.fullBleed ? '' : 'p2');
    var width = 640;
    if (this.props.size == 'big') { width = 960 }
    else if (this.props.size == 'small') { width = 320 }
    var styles = {
      container: {
        display: isOpen ? '' : 'none',
        position: 'fixed',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        zIndex: 4,
      },
      overlay: {
        position: 'absolute',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
      },
      modal: {
        position: 'relative',
        width: this.props.fullBleed ? 'auto' : width,
          //minWidth: '16rem',
        maxWidth: '100%',
        margin: 'auto',
        overflow: 'hidden',
        boxShadow: '0 4px 4px rgba(0,0,0,.1)',
      },
      dismissButton: this.buttonStyle,
    };
    if (this.props.fullBleed) {
      styles.modal.position = 'absolute';
      styles.modal.top = 0;
      styles.modal.right = 0;
      styles.modal.bottom = 0;
      styles.modal.left = 0;
      styles.modal.margin = 0;
    }

    return (
      <div className={classes.container}
        style={styles.container}>
        <a href="#!"
          style={styles.overlay}
          onClick={this.props.onDismiss}/>
        <div className="bg-white rounded"
          style={styles.modal}>
          <div className={classes.header}>
            <div className="bold p2 flex-auto">{header}</div>
            <button className="h3"
              style={styles.dismissButton}
              onClick={this.props.onDismiss}
              title="Dismiss modal overlay">
              &times;
            </button>
          </div>
          <div className={classes.body}>
            {this.props.children}
          </div>
        </div>
      </div>
    )

  }

});

==> rebass-0.0.3.tgz: package/src/modal.jsx <==

var React = require('react');
var classnames = require('classnames');
var colorbass = require('colorbass');

var Modal = React.createClass({

  getDefaultProps: function() {
    return {
      open: false,
      flush: false,
      fullBleed: false,
      size: 'medium',
      header: '',
      color: 'silver',
      onDismiss: function() {}
    }
  },

  render: function() {

    var open = this.props.open;
    var header = this.props.header;
    var bassClasses = colorbass(this.props.color);
    var classes = {
      body: classnames( this.props.flush ? '' : 'p2'),
      header: classnames('flex', 'flex-center', bassClasses.primary),
      container: classnames('flex flex-center overflow-auto bg-darken-3', { p2: !this.props.fullBleed }),
    };
    var width = 640;
    if (this.props.size == 'big') { width = 960 }
    else if (this.props.size == 'small') { width = 320 }

    var styles = {
      container: {
        display: open ? '' : 'none',
        position: 'fixed',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        zIndex: 4,
      },
      overlay: {
        position: 'absolute',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
      },
      modal: {
        position: 'relative',
        width: this.props.fullBleed ? 'auto' : width,
          //minWidth: '16rem',
        maxWidth: '100%',
        margin: 'auto',
        overflow: 'hidden',
        boxShadow: '0 4px 4px rgba(0,0,0,.1)',
      },
      //dismissButton: this.buttonStyle,
    };

    if (this.props.fullBleed) {
      styles.modal.position = 'absolute';
      styles.modal.top = 0;
      styles.modal.right = 0;
      styles.modal.bottom = 0;
      styles.modal.left = 0;
      styles.modal.margin = 0;
    }

    return (
      <div className={classes.container}
        style={styles.container}>
        <a href="#!"
          style={styles.overlay}
          onClick={this.props.onDismiss}/>
        <div className="bg-white rounded"
          style={styles.modal}>
          <div className={classes.header}>
            <div className="bold p2 flex-auto">{header}</div>
            <button className="h3 button button-transparent muted"
              onClick={this.props.onDismiss}
              title="Dismiss modal overlay">
              &times;
            </button>
          </div>
          <div className={classes.body}>
            {this.props.children}
          </div>
        </div>
      </div>
    )

  }

});

module.exports = Modal;
